@@ -18,9 +18,6 @@
  *                                                                  *
  \********************************************************************/
 
-/*
- * $Id: client_list.c 901 2006-01-17 18:58:13Z mina $
- */
 /** @file client_list.c
   @brief Client List Functions
   @author Copyright (C) 2004 Alexandre Carmel-Veillex <acv@acv.ca>
@@ -36,7 +33,6 @@
 #include <pthread.h>
 #include <sys/wait.h>
 #include <sys/types.h>
-#include <unistd.h>
 
 #include <string.h>
 
@@ -117,7 +113,7 @@ _client_list_append(const char ip[], const char mac[], const char token[])
 
 	config = config_get_config();
 	maxclients = config->maxclients;
-	if(client_count >= maxclients) {
+	if (client_count >= maxclients) {
 		debug(LOG_NOTICE, "Already list %d clients, cannot add %s %s", client_count, ip, mac);
 		return NULL;
 	}
@@ -175,7 +171,7 @@ _client_list_append(const char ip[], const char mac[], const char token[])
 char *
 _client_list_make_auth_token(const char ip[], const char mac[])
 {
-	char *token;
+	char *token = NULL;
 
 	safe_asprintf(&token,"%04hx%04hx", rand16(), rand16());
 
@@ -194,7 +190,7 @@ client_list_add_client(const char ip[])
 	t_client *client;
 	char *mac, *token;
 
-	if(!check_ip_format(ip)) {
+	if (!check_ip_format(ip)) {
 		/* Inappropriate format in IP address */
 		debug(LOG_NOTICE, "Illegal IP format [%s]", ip);
 		return NULL;
@@ -217,7 +213,7 @@ client_list_add_client(const char ip[])
 	return client;
 }
 
-/** Finds a  client by its IP and MAC, returns NULL if the client could not
+/** Finds a client by its IP and MAC, returns NULL if the client could not
  * be found
  * @param ip IP we are looking for in the linked list
  * @param mac MAC we are looking for in the linked list
@@ -261,9 +257,9 @@ client_list_find_by_ip(const char ip[])
 }
 
 /**
- * Finds a  client by its Mac, returns NULL if the client could not
+ * Finds a client by its MAC, returns NULL if the client could not
  * be found
- * @param mac Mac we are looking for in the linked list
+ * @param mac MAC we are looking for in the linked list
  * @return Pointer to the client, or NULL if not found
  */
 t_client *
