@@ -18,9 +18,6 @@
  *                                                                  *
  \********************************************************************/
 
-/*
- * $Id: firewall.c 1162 2007-01-06 23:51:02Z benoitg $
- */
 /** @internal
   @file firewall.c
   @brief Firewall update functions
@@ -37,7 +34,6 @@
 #include <pthread.h>
 #include <sys/wait.h>
 #include <sys/types.h>
-#include <unistd.h>
 
 #include <string.h>
 
@@ -63,7 +59,6 @@
 #include <netinet/ip_icmp.h>
 #endif
 
-#include "httpd.h"
 #include "safe.h"
 #include "debug.h"
 #include "conf.h"
@@ -169,8 +164,8 @@ fw_refresh_client_list(void)
 			if (last_updated +  (config->checkinterval * config->clienttimeout) <= now) {
 				/* Timing out inactive user */
 				debug(LOG_NOTICE, "%s %s inactive %d secs. kB in: %llu  kB out: %llu",
-					  cp1->ip, cp1->mac, config->checkinterval * config->clienttimeout,
-					  cp1->counters.incoming/1000, cp1->counters.outgoing/1000);
+					cp1->ip, cp1->mac, config->checkinterval * config->clienttimeout,
+					cp1->counters.incoming/1000, cp1->counters.outgoing/1000);
 				if (cp1->fw_connection_state == FW_MARK_AUTHENTICATED) {
 					iptables_fw_access(AUTH_MAKE_DEAUTHENTICATED, cp1);
 				}
@@ -178,8 +173,8 @@ fw_refresh_client_list(void)
 			} else if (added_time +  (config->checkinterval * config->clientforceout) <= now) {
 				/* Forcing out user */
 				debug(LOG_NOTICE, "%s %s connected %d secs. kB in: %llu kB out: %llu",
-					  cp1->ip, cp1->mac, config->checkinterval * config->clientforceout,
-					  cp1->counters.incoming/1000, cp1->counters.outgoing/1000);
+					cp1->ip, cp1->mac, config->checkinterval * config->clientforceout,
+					cp1->counters.incoming/1000, cp1->counters.outgoing/1000);
 				if (cp1->fw_connection_state == FW_MARK_AUTHENTICATED) {
 					iptables_fw_access(AUTH_MAKE_DEAUTHENTICATED, cp1);
 				}
@@ -194,10 +189,10 @@ fw_refresh_client_list(void)
 const char *
 fw_connection_state_as_string(int mark)
 {
-	if(mark == FW_MARK_PREAUTHENTICATED) return "Preauthenticated";
-	if(mark == FW_MARK_AUTHENTICATED) return "Authenticated";
-	if(mark == FW_MARK_TRUSTED) return "Trusted";
-	if(mark == FW_MARK_BLOCKED) return "Blocked";
+	if (mark == FW_MARK_PREAUTHENTICATED) return "Preauthenticated";
+	if (mark == FW_MARK_AUTHENTICATED) return "Authenticated";
+	if (mark == FW_MARK_TRUSTED) return "Trusted";
+	if (mark == FW_MARK_BLOCKED) return "Blocked";
 	return "ERROR: unrecognized mark";
 }
 
