@@ -18,7 +18,6 @@
  *                                                                  *
 \********************************************************************/
 
-/* $Id: ndsctl_thread.c 969 2006-02-23 17:09:32Z papril $ */
 /** @file ndsctl_thread.c
     @brief Monitoring and control of nodogsplash, server part
     @author Copyright (C) 2004 Alexandre Carmel-Veilleux <acv@acv.ca>
@@ -41,7 +40,6 @@
 #include <errno.h>
 
 #include "common.h"
-#include "httpd.h"
 #include "util.h"
 #include "conf.h"
 #include "debug.h"
@@ -55,14 +53,11 @@
 #include "ndsctl_thread.h"
 
 /* Defined in clientlist.c */
-extern	pthread_mutex_t	client_list_mutex;
-extern	pthread_mutex_t	config_mutex;
+extern pthread_mutex_t client_list_mutex;
+extern pthread_mutex_t config_mutex;
 
 static void *thread_ndsctl_handler(void *);
-static void ndsctl_status(int);
-static void ndsctl_clients(int);
-static void ndsctl_json(int);
-static void ndsctl_stop(int);
+static void ndsctl_stop(pthread_t);
 static void ndsctl_block(int, char *);
 static void ndsctl_unblock(int, char *);
 static void ndsctl_allow(int, char *);
@@ -75,6 +70,11 @@ static void ndsctl_loglevel(int, char *);
 static void ndsctl_password(int, char *);
 static void ndsctl_username(int, char *);
 
+struct ndsctl_args {
+	int fd;
+	pthread_t ndsctl_master_id;
+};
+
 /** Launches a thread that monitors the control socket for request
 @param arg Must contain a pointer to a string containing the Unix domain socket to open
 @todo This thread loops infinitely, need a watchdog to verify that it is still running?
@@ -82,12 +82,13 @@ static void ndsctl_username(int, char *);
 void*
 thread_ndsctl(void *arg)
 {
-	int	sock,    fd;
-	char	*sock_name;
-	struct 	sockaddr_un	sa_un;
+	int sock, fd;
+	const char *sock_name;
+	struct sockaddr_un sa_un;
 	int result;
-	pthread_t	tid;
+	pthread_t tid;
 	socklen_t len;
+	struct ndsctl_args *child_thread_args;
 
 	debug(LOG_DEBUG, "Starting ndsctl.");
 
@@ -110,37 +111,34 @@ thread_ndsctl(void *arg)
 	unlink(sock_name);
 
 	debug(LOG_DEBUG, "Filling sockaddr_un");
-	strcpy(sa_un.sun_path, sock_name); /* XXX No size check because we
-				      * check a few lines before. */
+	strcpy(sa_un.sun_path, sock_name); /* XXX No size check because we check a few lines before. */
 	sa_un.sun_family = AF_UNIX;
 
-	debug(LOG_DEBUG, "Binding socket (%s) (%d)", sa_un.sun_path,
-		  strlen(sock_name));
+	debug(LOG_DEBUG, "Binding socket (%s) (%d)", sa_un.sun_path, strlen(sock_name));
 
 	/* Which to use, AF_UNIX, PF_UNIX, AF_LOCAL, PF_LOCAL? */
-	if (bind(sock, (struct sockaddr *)&sa_un, strlen(sock_name)
-			 + sizeof(sa_un.sun_family))) {
-		debug(LOG_ERR, "Could not bind control socket: %s",
-			  strerror(errno));
+	if (bind(sock, (struct sockaddr *)&sa_un, strlen(sock_name) + sizeof(sa_un.sun_family))) {
+		debug(LOG_ERR, "Could not bind control socket: %s", strerror(errno));
 		pthread_exit(NULL);
 	}
 
 	if (listen(sock, 5)) {
-		debug(LOG_ERR, "Could not listen on control socket: %s",
-			  strerror(errno));
+		debug(LOG_ERR, "Could not listen on control socket: %s", strerror(errno));
 		pthread_exit(NULL);
 	}
 
 	while (1) {
-
 		memset(&sa_un, 0, sizeof(sa_un));
-		len = (socklen_t) sizeof(sa_un); /* <<< ADDED BY DPLACKO */
+		len = (socklen_t) sizeof(sa_un);
 		if ((fd = accept(sock, (struct sockaddr *)&sa_un, &len)) == -1) {
-			debug(LOG_ERR, "Accept failed on control socket: %s",
-				  strerror(errno));
+			debug(LOG_ERR, "Accept failed on control socket: %s", strerror(errno));
+			pthread_exit(NULL);
 		} else {
 			debug(LOG_DEBUG, "Accepted connection on ndsctl socket %d (%s)", fd, sa_un.sun_path);
-			result = pthread_create(&tid, NULL, &thread_ndsctl_handler, (void *) (size_t) fd);
+			child_thread_args = calloc(1, sizeof(struct ndsctl_args));
+			child_thread_args->fd = fd;
+			child_thread_args->ndsctl_master_id = pthread_self();
+			result = pthread_create(&tid, NULL, &thread_ndsctl_handler, (void *) child_thread_args);
 			if (result != 0) {
 				debug(LOG_ERR, "FATAL: Failed to create a new thread (ndsctl handler) - exiting");
 				termination_handler(0);
@@ -152,18 +150,18 @@ thread_ndsctl(void *arg)
 	return NULL;
 }
 
-
 static void *
 thread_ndsctl_handler(void *arg)
 {
-	int fd, done, i;
+	int done, i;
 	char request[MAX_BUF];
 	ssize_t read_bytes, len;
+	struct ndsctl_args *args = arg;
+	pthread_t ndsctl_master = args->ndsctl_master_id;
+	int fd = args->fd;
+	free(args);
 
 	debug(LOG_DEBUG, "Entering thread_ndsctl_handler....");
-
-	fd = (int) (size_t) arg;
-
 	debug(LOG_DEBUG, "Read bytes and stuff from %d", fd);
 
 	/* Init variables */
@@ -196,7 +194,7 @@ thread_ndsctl_handler(void *arg)
 	} else if (strncmp(request, "json", 4) == 0) {
 		ndsctl_json(fd);
 	} else if (strncmp(request, "stop", 4) == 0) {
-		ndsctl_stop(fd);
+		ndsctl_stop(ndsctl_master);
 	} else if (strncmp(request, "block", 5) == 0) {
 		ndsctl_block(fd, (request + 6));
 	} else if (strncmp(request, "unblock", 7) == 0) {
@@ -237,62 +235,17 @@ thread_ndsctl_handler(void *arg)
 	return NULL;
 }
 
-static void
-ndsctl_status(int fd)
-{
-	char *status = NULL;
-	int len = 0;
-
-	status = get_status_text();
-	len = strlen(status);
-
-	write(fd, status, len);
-
-	free(status);
-}
-
-static void
-ndsctl_clients(int fd)
-{
-	char * status = NULL;
-	int len = 0;
-
-	status = get_clients_text();
-	len = strlen(status);
-
-	write(fd, status, len);
-
-	free(status);
-}
-
-static void
-ndsctl_json(int fd)
-{
-	char * status = NULL;
-	int len = 0;
-
-	status = get_clients_json();
-	len = strlen(status);
-
-	write(fd, status, len);
-
-	free(status);
-}
-
 /** A bit of an hack, self kills.... */
 static void
-ndsctl_stop(int fd)
+ndsctl_stop(pthread_t ndsctl_master_id)
 {
-	pid_t	pid;
-
-	pid = getpid();
-	kill(pid, SIGINT);
+	pthread_cancel(ndsctl_master_id);
 }
 
 static void
 ndsctl_auth(int fd, char *arg)
 {
-	t_client	*client;
+	t_client *client;
 	char *ip, *mac;
 	debug(LOG_DEBUG, "Entering ndsctl_auth...");
 
@@ -328,7 +281,7 @@ ndsctl_auth(int fd, char *arg)
 static void
 ndsctl_deauth(int fd, char *arg)
 {
-	t_client	*client;
+	t_client *client;
 	char *ip, *mac;
 	debug(LOG_DEBUG, "Entering ndsctl_deauth...");
 
