@@ -18,7 +18,6 @@
  *                                                                  *
 \********************************************************************/
 
-/* $Id: util.h 969 2006-02-23 17:09:32Z papril $ */
 /** @file util.h
     @brief Misc utility functions
     @author Copyright (C) 2004 Philippe April <papril777@yahoo.com>
@@ -27,8 +26,6 @@
 #ifndef _UTIL_H_
 #define _UTIL_H_
 
-#define STATUS_BUF_SIZ	16384
-
 /** @brief Execute a shell command
  */
 int execute(const char cmd_line[], int quiet);
@@ -62,17 +59,18 @@ int is_auth_online();
  */
 char *get_uptime_string();
 /*
- * @brief Creates a human-readable paragraph of the status of the nodogsplash process
+ * @brief Writes a human-readable paragraph of the status of the nodogsplash process
  */
-char *get_status_text();
+void ndsctl_status(int fd);
 /*
- * @brief Creates a machine-readable dump of currently connected clients
+ * @brief Writes a machine-readable dump of currently connected clients
  */
-char *get_clients_text();
+void ndsctl_clients(int fd);
+
 /*
- * @brief Creates a machine-readable json of currently connected clients
+ * @brief Writes a machine-readable json of currently connected clients
  */
-char *get_clients_json();
+void ndsctl_json(int fd);
 
 /** @brief cheap random */
 unsigned short rand16(void);
